<?php
/* * ***********************************************************************
 * Example App for Watchful
 * Copyright (c) 2006-2020 Watchful
 * ************************************************************************
 * Watchful.net is a web site monitoring and security service.
 * 
 * Although Watchful.net is a paid service, this program is free software;
 * you can redistribute it and/or modify it under the terms of the GNU 
 * General Public License as published by the Free Software Foundation; 
 * either version 2 of the License, or (at your option) any later version.
 *
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 * ************************************************************************
 * Get the latest version of this program at: https://watchful.net
 * *********************************************************************** */

// no direct access
defined('_JEXEC') or die();

//Require the watchfulliApps class from Watchful.net component
require_once(JPATH_ADMINISTRATOR . '/components/com_watchfulli/classes/apps.php');
// We extend a base class to pass additional parameters in the language strings
// It will probably be included in the client but we also put it here so the app will work
// even for older version of the Watchful client.
class ExampleAppAlert extends AppAlert
{
    public $parameter1;
    public $parameter2;
    public $parameter3;

    public function ExampleAppAlert($level, $message, $parameter1 = null, $parameter2 = null, $parameter3 = null)
    {
        if ($level != null && $message != null)
        {
            $this->level = $level;
            $this->message = $message;
            $this->parameter1 = $parameter1;
            $this->parameter2 = $parameter2;
            $this->parameter3 = $parameter3;
        }
    }

}
/**
 * The class name follows this pattern : plg<PluginGroup><PluginName>
 */
class plgWatchfulliAppsExampleApp extends watchfulliApps
{

    public function createAppAlert($level, $message, $parameter1 = null, $parameter2 = null, $parameter3 = null)
    {
        $alert = new ExampleAppAlert($level, $message, $parameter1, $parameter2, $parameter3);
        $this->addAlert($alert);
    }

    /**
     * Main program
     * 
     * @param string @oldValuesSerialized old values for the plugins
     */
    public function appMainProgram($oldValuesSerialized = null)
    {
        $this->setName("exampleApp"); //Unique app name
        $this->setDescription("Example App for Watchful - This App always generates an alert."); //App Description
        $debug = $this->params->get('debug', 0);

        // Do some check
        $newValue = $this->customCheck();
        if ($debug)
            $this->createAppAlert(1, "[DEBUG] New value is: " . $newValue); //Message to be displayed

            
//Looking for an old value
        $oldValue = $this->readExAppValue($oldValuesSerialized);

        if ($debug)
            $this->createAppAlert(1, "[DEBUG] Old value is: " . $oldValue); //Message to be displayed

        if ($oldValue == null) //First Time the app is triggered
        {
            $this->createAppValue('exampleApp', 'First time inserted');
            $this->createAppAlert(1, "First time inserted"); //Message to be displayed
        }
        else if ($oldValue != $newValue) //There is an old value and it's changed
        {
            //$this->createAppAlert(Error Level, Message);
            //Error Level :
            //1 = Warning
            //2 = Error
            $this->updateAppValue('exampleApp', $newValue); //send the new value
            $this->createAppAlert(1, "Value updated"); //Message to be displayed
        }
        else
        {
            if ($debug)
                $this->createAppAlert(1, "No changes."); //Message to be displayed
        }

        return $this;
    }

    /**
     * Do a custom check
     * 
     * @return string
     */
    public function customCheck()
    {
        // Here you will do whatever check you like on your site
        return "Sample value";
    }

}
